@@ -858,6 +858,7 @@ pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
 pref("network.IDN.whitelist.lu", true);
+pref("network.IDN.whitelist.lv", true);
 pref("network.IDN.whitelist.no", true);
 pref("network.IDN.whitelist.nu", true);
 pref("network.IDN.whitelist.nz", true);
@@ -886,6 +887,9 @@ pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
 pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// lk, Sri Lanka, .<Lanka> and .<Ilangai>
+pref("network.IDN.whitelist.xn--fzc2c9e2c", true);
+pref("network.IDN.whitelist.xn--xkc2al3hye2a", true);
 // qa, Qatar, .<Qatar>
 pref("network.IDN.whitelist.xn--wgbl6a", true);
 // ru, Russian Federation, .<RF>
@@ -895,11 +899,14 @@ pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true);
 pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
 pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
 pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// sy, Syria, .<Souria>
+pref("network.IDN.whitelist.xn--ogbpf8fl", true);
 // tw, Taiwan, <.Taiwan> with variants
 pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
 pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
+pref("network.IDN.whitelist.asia", true);
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
@@ -985,7 +992,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 949 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 956 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1374,20 +1381,20 @@ pref("editor.positioning.offset",            0);
 pref("dom.max_chrome_script_run_time", 20);
 pref("dom.max_script_run_time", 10);
 
-//@line 1338 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1345 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 // How long a plugin is allowed to process a synchronous IPC message
 // before we consider it "hung".
 pref("dom.ipc.plugins.timeoutSecs", 45);
 // How long a plugin launch is allowed to take before
 // we consider it failed.
 pref("dom.ipc.plugins.processLaunchTimeoutSecs", 45);
-//@line 1349 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1356 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Disable oopp for standard java. They run their own process isolation (which
 // conflicts with our implementation, at least on Windows).
 pref("dom.ipc.plugins.java.enabled", false);
 
-//@line 1363 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1371 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 
 pref("svg.smil.enabled", true);
 
@@ -1424,9 +1431,9 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1829 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1837 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 1831 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1839 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 // Mac specific preference defaults
 pref("browser.drag_out_of_frame_style", 1);
 pref("ui.key.saveLink.shift", false); // true = shift, false = meta
@@ -1851,22 +1858,22 @@ pref("ui.panel.default_level_parent", false);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2257 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2265 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2457 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2465 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2553 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2561 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2822 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2830 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3097 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3105 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3123 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
-
-//@line 3143 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3131 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 
 //@line 3151 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 
+//@line 3159 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
 pref("signon.SignonFileName",               "signons.txt"); // obsolete 
@@ -1939,9 +1946,9 @@ pref("webgl.osmesalib", "");
 pref("webgl.verbose", false);
 pref("webgl.prefer-native-gl", false);
 
-//@line 3230 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3238 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3235 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3243 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to disable acceleration for all widgets.
 pref("layers.acceleration.disabled", false);
@@ -1949,7 +1956,7 @@ pref("layers.acceleration.disabled", false);
 // Whether to force acceleration on, ignoring blacklists.
 pref("layers.acceleration.force-enabled", false);
 
-//@line 3254 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3262 "/builds/slave/2.0-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
